@@ -3,7 +3,7 @@ package Assert::Refute;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 NAME
 
@@ -24,7 +24,19 @@ uniformly both inside C<contract> blocks and in a unit-testing script.
 
 =head1 SYNOPSIS
 
-    use Assert::Refute;
+The following would die if C<$foo> doesn't meet the requirements:
+
+    use Assert::Refute { on_fail => 'croak' };
+
+    my $foo = frobnicate();
+    refute_these {
+        like $foo->{text}, qr/f?o?r?m?a?t/;
+        is $foo->{error}, undef;
+    };
+
+Or if you want more control over the execution of checks:
+
+    use Assert::Refute qw(:all);
 
     my $spec = contract {
         my ($foo, $bar) = @_;
@@ -38,6 +50,10 @@ uniformly both inside C<contract> blocks and in a unit-testing script.
     $report->is_passing; # true
     $report->get_tap;    # printable summary *as if* it was Test::More
 
+Note that Assert::Refute aims to be as non-invasive as possible.
+You can muffle condition checks at will or make them fatal,
+or copy them from production code to a unit-test.
+
 =head1 REFUTATIONS AND CONTRACTS
 
 C<refute($condition, $message)> stands for an inverted assertion.
@@ -62,15 +78,42 @@ assertions, tests, and validations.
 
 =head1 EXPORT
 
-All of the below functions are exported by default,
-as well as some basic assumptions mirroring the L<Test::More> suite.
+Per-package configuration parameters can be passed as hash refs in
+use statement. Anything that is I<not> hash is passed to exporter module:
+
+    use Assert::Refute { on_fail => 'croak' }, "carp_assert";
+
+Or more generally (though without any meaning and likely to die in the future):
+
+    use Assert::Refute { foo => 42 }, "refute", "contract", { bar => 137 };
+
+Valid configuration parameters are:
+
+=over
+
+=item * on_pass => skip|carp|croak - what to do when conditions are met.
+The default is skip, i.e. do nothing.
+
+=item * on_fail => skip|carp|croak - what to do when conditions are I<not> met.
+The default is carp (issue a warning and continue on, even with wrong data).
+
+=back
+
+All of the below functions are exported by default.
+
+    use Assert::Refute;
+
+as well as
 
     use Assert::Refute qw(:core);
 
 would only export C<contract>, C<refute>,
 C<contract_is>, C<subcontract>, and C<current_contract> functions.
 
-    use Assert::Refute qw(:basic);
+Also for convenience some basic assumptions mirroring the L<Test::More> suite
+are exportable via C<:all> export tag.
+
+    use Assert::Refute qw(:all);
 
 would export the following testing primitives:
 
@@ -95,14 +138,57 @@ use Assert::Refute::T::Basic;
 my @basic = (
     @Assert::Refute::T::Basic::EXPORT,
 );
-my @core  = qw( contract current_contract refute subcontract contract_is );
+my @core  = qw(
+    contract refute_these
+    refute subcontract contract_is current_contract
+);
 
 our @ISA = qw(Exporter);
-our @EXPORT = (@core, @basic);
+our @EXPORT = @core;
+our @EXPORT_OK = @basic;
 
 our %EXPORT_TAGS = (
     basic => \@basic,
     core  => \@core,
+    all   => [@core, @basic],
+);
+
+our $DRIVER;
+our %CALLER_CONF;
+
+sub import {
+    my $class = shift;
+    my (%conf, @exp);
+    foreach (@_) {
+        if (ref $_ eq 'HASH') {
+            %conf = (%conf, %$_);
+        } elsif (!ref $_) {
+            push @exp, $_;
+        } else {
+            croak "Unexpected argument in Assert::Refute->import: ".ref $_;
+        };
+    };
+
+    $class->configure( \%conf, scalar caller );
+    $class->export_to_level(1, undef, @exp);
+};
+
+my %known_callback = (
+    skip => '',
+    carp => sub {
+        my $report = shift;
+        carp $report->get_tap
+            .($report->is_passing ? "Contract passed" : "Contract failed");
+    },
+    croak => sub {
+        my $report = shift;
+        croak $report->get_tap
+            .($report->is_passing ? "Contract passed" : "Contract failed");
+    },
+);
+my %default_conf = (
+    on_fail => 'carp',
+    on_pass => 'skip',
 );
 
 =head2 contract { ... }
@@ -149,6 +235,50 @@ sub contract (&@) { ## no critic
     return Assert::Refute::Contract->new( %opt );
 };
 
+=head2 refute_these { ... }
+
+Refute several conditions, warn or die if they fail,
+as requested during C<use> of this module.
+The coderef shall accept one argument, the contract execution object
+(likely a L<Assert::Refute::Exec>, see C<need_object> above).
+
+More arguments MAY be added in the future.
+Return value is ignored.
+A contract report object is returned instead.
+
+This is basically what one expects from a module in C<Assert::*> namespace.
+
+B<[EXPERIMENTAL]> This name is preliminary and is likely to change
+in the nearest future.
+It will stay available (with a warning) for at least 5 releases after that.
+
+=cut
+
+sub refute_these(&;@) { ## no critic # need prototype
+    my ( $block, @arg ) = @_;
+
+    # Should a missing config even happen? Ok, play defensively...
+    my $conf = $CALLER_CONF{+caller}
+        || __PACKAGE__->configure( {}, scalar caller );
+
+    # This is generally a ripoff of A::R::Contract->apply
+    my $report = Assert::Refute::Exec->new;
+    local $DRIVER = $report;
+    eval {
+        $block->($report);
+        $report->done_testing(0);
+        1;
+    } || do {
+        $report->done_testing($@ || "refute_these block was interrupted");
+    };
+
+    # perform whatever action is needed
+    my $callback = $conf->{ $report->is_passing ? "on_pass" : "on_fail" };
+    $callback->($report) if $callback;
+
+    return $report;
+};
+
 =head2 refute( $condition, $message )
 
 Test a condition using the current contract.
@@ -215,6 +345,94 @@ Dies if no contract is being executed at the time.
 
 This is actually a clone of L<Assert::Refute::Build/current_contract>.
 
+=head1 STATIC METHODS
+
+Use these methods to configure Assert::Refute globally.
+There's of course always purely object-oriented L<Assert::Refute::Contract>
+for even more fine-grained control.
+
+=head2 configure
+
+    Assert::Refute->configure( \%options );
+    Assert::Refute->configure( \%options, "My::Package");
+
+Set per-caller package configuration values for given package.
+Called implicitly C<use Assert::Refute { ... }> if parameters are given.
+
+These are adhered to by L</refute_these>, mostly.
+
+Available %options include:
+
+=over
+
+=item * on_pass - callback to execute if tests pass (default: C<skip>)
+
+=item * on_fail - callback to execute if tests fail (default: C<carp>,
+but not just C<Carp::carp> - see below).
+
+=back
+
+The callbacks MUST be either
+a C<CODEREF> accepting L<Assert::Refute::Report> object,
+or one of predefined strings:
+
+=over
+
+=item * skip - do nothing;
+
+=item * carp - warn the stringified report;
+
+=item * croak - die with stringified report as error message;
+
+=back
+
+Returns the resulting config (with default values added,etc).
+
+=cut
+
+my %conf_known;
+$conf_known{$_}++ for qw( on_pass on_fail );
+
+sub configure {
+    my ($class, $conf, $caller) = @_;
+
+    my @extra = grep { !$conf_known{$_} } keys %$conf;
+    croak "$class->configure: unknown parameters (@extra)"
+        if @extra;
+
+    # configure whoever called us by default
+    $caller ||= scalar caller;
+
+    $conf = { %default_conf, %$conf };
+    $conf->{on_fail} = _coerce_cb($conf->{on_fail});
+    $conf->{on_pass} = _coerce_cb($conf->{on_pass});
+
+    $CALLER_CONF{$caller} = $conf;
+};
+
+=head2 get_config
+
+Returns configuration from above, initializing with defaults if needed.
+
+=cut
+
+sub get_config {
+    my ($class, $caller) = @_;
+
+    $caller ||= scalar caller;
+    return $CALLER_CONF{$caller} ||= $class->configure({}, $caller);
+};
+
+sub _coerce_cb {
+    my $sub = shift;
+
+    $sub = defined $known_callback{$sub} ? $known_callback{$sub} : $sub;
+    return unless $sub;
+    croak "Bad callback $sub"
+        unless ref $sub and UNIVERSAL::isa( $sub, 'CODE' );
+    return $sub;
+};
+
 =head1 EXTENDING THE SUITE
 
 Although building wrappers around C<refute> call is easy enough,
