@@ -3,7 +3,7 @@ package Assert::Refute::Build;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 NAME
 
@@ -34,7 +34,7 @@ Extending the test suite goes as follows:
 
 This can be later used inside production code to check a condition:
 
-    use Assert::Refute;
+    use Assert::Refute qw(:all);
     use My::Package;
     my $fun_check = contract {
         is_everything( shift );
@@ -65,8 +65,6 @@ use Scalar::Util qw(weaken blessed set_prototype looks_like_number refaddr);
 use parent qw(Exporter);
 our @EXPORT = qw(build_refute current_contract to_scalar);
 
-our $BACKEND;
-
 # NOTE HACK
 # If we're being loaded after Test::More, we're *likely* inside a test script
 # This has to be re-done properly
@@ -226,12 +224,12 @@ Dies if no contract is being executed at the time.
 =cut
 
 sub current_contract() { ## nocritic
-    return $BACKEND if $BACKEND;
+    return $Assert::Refute::DRIVER if $Assert::Refute::DRIVER;
 
     # Would love to just die, but...
     if ($MORE_DETECTED) {
         require Assert::Refute::Driver::More;
-        return $BACKEND = Assert::Refute::Driver::More->new;
+        return $Assert::Refute::DRIVER = Assert::Refute::Driver::More->new;
     };
 
     croak "Not currently testing anything";
