@@ -3,7 +3,7 @@ package Assert::Refute::Exec;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 NAME
 
@@ -134,10 +134,19 @@ After this call, no more writes (including done_testing)
 can be performed on this contract.
 This happens by default at the end of C<contract{ ... }> block.
 
-If an argument is given, it is considered to be the exception
+Dies if called for a second time, I<unless> an argument is given.
+
+A true argument is considered to be the exception
 that interrupted the contract execution,
 resulting in an unconditionally failed contract.
 
+A false argument just avoids dying and is equivalent to
+
+    $report->done_testing
+        unless $report->is_done;
+
+Returns self.
+
 =cut
 
 sub done_testing {
@@ -150,13 +159,14 @@ sub done_testing {
         $self->refute( $exception, "unexpected exception: $exception" );
         $self->do_log( 0, 1, "Looks like test execution was interrupted" );
     } elsif ($self->{done}) {
-        $self->_croak( $ERROR_DONE )
+        return $self if defined $exception;
+        $self->_croak( $ERROR_DONE );
     } else {
         $self->do_log(0, 0, "1..$self->{count}");
     };
     $self->do_log(0, 1,
-        "Looks like $self->{failed} tests of $self->{count} have failed")
-            if $self->{failed};
+        "Looks like $self->{fail_count} tests of $self->{count} have failed")
+            if $self->{fail_count};
 
     $self->{done}++;
     return $self;
@@ -229,7 +239,7 @@ Tell whether the contract is passing or not.
 sub is_passing {
     my $self = shift;
 
-    return !$self->{failed} && !$self->{has_error};
+    return !$self->{fail_count} && !$self->{has_error};
 };
 
 =head3 get_count
@@ -243,6 +253,17 @@ sub get_count {
     return $self->{count};
 };
 
+=head3 get_fail_count
+
+How many tests failed
+
+=cut
+
+sub get_fail_count {
+    my $self = shift;
+    return $self->{fail_count} || 0;
+};
+
 =head3 get_tests
 
 Returns a list of test ids, preserving order.
@@ -394,16 +415,14 @@ Levels are:
 =cut
 
 sub do_log {
-    my ($self, $indent, $level, @parts) = @_;
+    my ($self, $indent, $level, $mess) = @_;
 
     $self->_croak( $ERROR_DONE )
         if $self->{done};
 
     $indent += $self->{indent};
 
-    foreach (@parts) {
-        push @{ $self->{mess} }, [$indent, $level, $_];
-    };
+    push @{ $self->{mess} }, [$indent, $level, $mess];
 
     return $self;
 };
@@ -440,7 +459,7 @@ sub set_result {
         if exists $self->{fail}{$id};
 
     push @{ $self->{list} }, $id;
-    $self->{failed}++ if $result;
+    $self->{fail_count}++ if $result;
     $self->{fail}{$id} = $result;
 
     return $self;
