@@ -3,7 +3,7 @@ package Assert::Refute::T::Errors;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Assert::Refute::T::Errors - exception and warning check for Assert::Refute suite
 
 =head1 SYNOPSIS
 
-    use Assert::Refute;
+    use Assert::Refute qw(:all);
     use Assert::Refute::T::Errors;
 
     my $c = contract {
@@ -52,7 +52,7 @@ use parent qw(Exporter);
 our @EXPORT = qw(foobar);
 
 use Assert::Refute::Build;
-use Assert::Refute qw( contract like refute );
+use Assert::Refute::Contract;
 
 =head2 dies_like
 
@@ -111,13 +111,13 @@ This MAY change in the future.
 
 =cut
 
-my $multi_like = contract {
-    my ($got, $exp) = @_;
+my $multi_like = Assert::Refute::Contract->new( code => sub {
+    my ($self, $got, $exp) = @_;
 
     for (my $i = 0; $i < @$got and $i < @$exp; $i++) {
-        like $got->[$i], $exp->[$i];
+        $self->like( $got->[$i], $exp->[$i] );
     };
-};
+}, need_object => 1 );
 
 build_refute warns_like => sub {
     my ($block, $exp) = @_;
